#
# spec file for package bzr
#
# Copyright (c) 2007 SUSE LINUX Products GmbH, Nuernberg, Germany.
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

Name:           bzr
Version:        1.6.1
Release:        1.2
License:        GNU General Public License (GPL)
Group:          Development/Tools/Version Control
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
# For the emacs and xemacs subpackages
BuildRequires:  emacs-nox 
%if 0%{?suse_version}
BuildRequires:  pyrex xemacs
%endif
# for the bash and zsh subpackages
BuildRequires:  bash zsh

%if 0%{?suse_version}

# New pythons have this.
%if 0%{?suse_version} < 1030
BuildRequires:  python-elementtree
Requires:       python-elementtree
%endif

# They all needs this, however.
%{py_requires}

# And they all can make use of this.
Recommends:     python-curl

%else
Requires:       python
Requires:       python-pycurl
%endif

URL:            http://bazaar-vcs.org/
Source:         bzr-%{version}.tar.bz2
# Source:         bzr-1.5rc1.tar.bz2
Summary:        Friendly distributed version control system

%description
Bazaar-NG is a distributed revision control system that is powerful,
friendly, and scalable.  It is the successor of the bazaar RCS which, in
turn, was a user-friendly reimplementation of GNU Arch.

Authors:
--------
    Martin Pool <mbp@canonical.com>
    Robert Collins <robert.collins@canonical.com>

%package sftp
Summary:        sftp support for bzr
Group:          Development/Tools/Version Control
Requires:       %{name} = %{version}
Requires:       python-paramiko

%description sftp
sftp support for bzr.

%package emacs
Summary:        Emacs mode for bzr
Group:          Development/Tools/Version Control
Requires:       %{name} = %{version}
Requires:       emacs

%description emacs
Emacs mode for bzr.

%if 0%{?suse_version}
%package xemacs
Summary:        XEmacs mode for bzr
Group:          Development/Tools/Version Control
Requires:       %{name} = %{version}
Requires:       xemacs

%description xemacs
XEmacs mode for bzr.
%endif

%package bash
Summary:        bash completion for bzr commands
Group:          Development/Tools/Version Control
Requires:       %{name} = %{version}
Requires:       bash

%description bash
bash completion for bzr commands.

%if 0
%package zsh
Summary:        zsh completion for bzr commands
Group:          Development/Tools/Version Control
Requires:       %{name} = %{version}
Requires:       zsh

%description zsh
zsh completion for bzr commands.  (Unimplemented.)
%endif

%debug_package
%prep
%setup -q -n bzr-1.6.1

%build
python setup.py build

%install
%if 0%{?suse_version}
%define __record_arg --record-rpm
%else
%define __record_arg --record
%endif
python setup.py install --root %{buildroot} --prefix %{_prefix} %__record_arg %{name}.files --install-data %{_datadir}
# manpages are compressed
perl -pi -e 's|(%{_mandir}.*\.1)|$1.gz|g' %{name}.files
# /usr/share/man and /usr/share/man1 shouldn't be packaged
cat %{name}.files | grep -v '%dir /usr/share/man' > %{name}.files.tmp && mv %{name}.files.tmp %{name}.files

# install emacs modes
%{__install} -D -m 0644 contrib/emacs/bzr-mode.el $RPM_BUILD_ROOT/%{_datadir}/emacs/site-lisp/bzr-mode.el
%if 0%{?suse_version}
%{__install} -D -m 0644 contrib/emacs/bzr-mode.el $RPM_BUILD_ROOT/%{_datadir}/xemacs/site-lisp/bzr-mode.el
%endif

# install shell completion
%{__install} -D -m 0644 contrib/bash/bzr.simple $RPM_BUILD_ROOT/%{_sysconfdir}/bash_completion.d/bzr.simple.sh
# hmm, how to best install the zsh stuff?

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(-,root,root,-)
%doc *.TODO COPYING.txt INSTALL NEWS* README TODO *.ico
%doc tools/ doc/* contrib/

%files sftp

%files emacs
%defattr(-,root,root)
%{_datadir}/emacs/site-lisp/bzr-mode.el

%if 0%{?suse_version}
%files xemacs
%defattr(-,root,root)
%{_datadir}/xemacs/site-lisp/bzr-mode.el
%endif

%files bash
%defattr(-,root,root)
%{_sysconfdir}/bash_completion.d/bzr.simple.sh

%if 0
%files zsh
%defattr(-,root,root)
%endif

%changelog
* Fri Sep  5 2008 maw@suse.de
- Update to version 1.6.1:
  + Fix several regressions in 1.6
  + Users who had used --1.6-rich-root are advised to upgrade with
  - -1.6.1-rich-root
  + For a fuller account of the changes in bzr 1.6.1, including
    bug fixes, see https://launchpad.net/bzr/1.6/1.6.1.
* Mon Aug 25 2008 maw@suse.de
- Update to version 1.6:
  + New features:
  * Stacked branches
  * Improved weave merge
  * Updated server protocol (now on v3) which will allow for
    better cross version compatibility
  + Knit format repositories have been deprecated:
  * It's recommended that users upgrade them
  * Reading and writing knit format repositories will be
    supported for the forseeable future
  * They will no longer receive any performance tuning
  + For a fuller account of the changes in bzr 1.6, including
    bug fixes, see https://launchpad.net/bzr/1.6/1.6/.
* Sun May 18 2008 maw@suse.de
- Update to version 1.5:
  + CHANGES:
  * Suppress deprecation warnings when bzrlib is a 'final'
    release; this way users of packaged software won't be
    bothered with DeprecationWarnings, but developers and testers
    will still see them
  + DOCUMENTATION:
  * Improved the plugin and integration chapters of the User
    Guide.
* Fri May 16 2008 maw@suse.de
- Update to 1.5 RC1:
  + Mostly a bugfix release
  + Several performance improvements, impacting bzr diff, bzr
    status, and bzr pull; the conversion from dirstate/pack
    branches into rich-root(pack) has been improved, paving the way
    for rich-root-pack to become the default format within the next
    few releases; this will make interoperating with a subversion
    repository more seamless, as bzr-svn has required local
    repositories to be in rich-root(-pack) formats
  + Improved user and developer documentation
  + Authors of plugins that install hooks should be aware that
    install_hook has been deprecated in favor of install_named_hook
  + Graph.find_differences() and Graph.find_unique_ancestors() are
    able to correctly compute ancestry difference operations,
    without having to traverse all of history; this has been
    integrated into 'bzr status' but still needs to be used in
    commands like 'bzr missing'.
* Thu May 15 2008 maw@suse.de
- Require python-pycurl on Red Hat derived systems.
* Thu May 15 2008 maw@suse.de
- Recommend python-curl on various SUSE distros.
* Fri May  2 2008 maw@suse.de
- Fix build on Fedora (maybe).
* Fri May  2 2008 maw@suse.de
- Update to 1.4 final:
  + BUG FIXES:
  * Pushing a branch in "dirstate" format (Branch5) over bzr+ssh
    would break if the remote server was < version 1.2; This was
    due to a bug in the RemoteRepository.get_parent_map()
    fallback code.
* Tue Apr 22 2008 maw@suse.de
- Update to 1.4 RC2:
  + BUG FIXES:
  * ``bzr log -r ..X bzr://`` was failing, because it was getting
    a request for ``revision_id=None`` which was not a string
  * Fixed a bug in handling ghost revisions when logging changes
    in a particular file
  * Fix error about "attempt to add line-delta in non-delta knit"
  * Fixed performance degradation in fetching from knit
    repositories to knits and packs due to parsing the entire
    revisions.kndx on every graph walk iteration fixed by using
    the Repository.get_graph API; there was another regression
    in knit => knit fetching which re-read the index for every
    revision each side had in common.
* Thu Apr 17 2008 maw@suse.de
- Update to 1.4 RC1:
  + CHANGES:
  * bzr main script cannot be imported
  * On Linux bzr additionally looks for plugins in
    arch-independent site directory
  * The ``set_rh`` branch hook is now deprecated; please migrate
    any plugins using this hook to use an alternative, e.g.
    ``post_change_branch_tip``
  * When a plugin cannot be loaded as the file path is not a valid
    python module name bzr will now strip a ``bzr_`` prefix from the
    front of the suggested name, as many plugins (e.g. bzr-svn)
    want to be installed without this prefix. It is a common mistake
    to have a folder named "bzr-svn" for that plugin, especially
    as this is what bzr branch lp:bzr-svn will give you
  * UniqueIntegerBugTracker now appends bug-ids instead of joining
    them to the base URL. Plugins that register bug trackers may
    need a trailing / added to the base URL if one is not already there
  + FEATURES:
  * Added mail-mode GNU Emacs mail package as a mail_client
  * Added start_commit hook for mutable trees
  * ``status`` now accepts ``--no-pending`` to show the status without
    listing pending merges, which speeds up the command a lot on large
    histories
  * New ``post_change_branch_tip`` hook that is called after the
    branch tip is moved but while the branch is still write-locked.
    See the User Reference for signature details
  + IMPROVEMENTS:
  * The smart protocol now has support for setting branches' revision info
    directly. This should make operations like push slightly faster, and is a
    step towards server-side hooks. The new request method name is
    ``Branch.set_last_revision_info``
  * ``bzr commit --fixes`` now recognises "gnome" as a tag by default
  * ``bzr switch`` will attempt to find branches to switch to relative
    to the current branch. E.g. ``bzr switch branchname`` will look for
    ``current_branch/../branchname``
  * Diff is now more specific about execute-bit changes it describes
  * Fetching data over HTTP is a bit faster when urllib is used. This is done
    by forcing it to recv 64k at a time when reading lines in HTTP headers,
    rather than just 1 byte at a time
  * Log --short and --line are much faster when -r is not specified
  * Merge is faster. We no longer check a file's existence unnecessarily
    when merging the execute bit
  * ``bzr status`` on an explicit list of files no longer shows pending
    merges, making it much faster on large trees
  * The launchpad directory service now warns the user if they have not set
    their launchpad login and are trying to resolve a URL using it, just
    in case they want to do a write operation with it
  * The smart protocol client is slightly faster, because it now only queries
    the server for the protocol version once per connection. Also, the HTTP
    transport will now automatically probe for and use a smart server if
    one is present. You can use the new ``nosmart+`` transport decorator
    to get the old behaviour
  * The ``version`` command takes a ``--short`` option to print just the
    version number, for easier use in scripts
  * Various operations with revision specs and commands that calculate
    revnos and revision ids are faster
  + BUGFIXES:
  * Add ``root_client_path`` parameter to SmartWSGIApp and
    SmartServerRequest. This makes it possible to publish filesystem
    locations that don't exactly match URL paths. SmartServerRequest
    subclasses should use the new ``translate_client_path`` and
    ``transport_from_client_path`` methods when dealing with paths received
    from a client to take this into account
  * ``bzr mv a b`` can be now used also to rename previously renamed
    directories, not only files
  * ``bzr uncommit --local`` can now remove revisions from the local
    branch to be symmetric with ``bzr commit --local``
  * Don't ask for a password if there is no real terminal
  * Fix a bug causing a ValueError crash in ``parse_line_delta_iter`` when
    fetching revisions from a knit to pack repository or vice versa using
    bzr:// (including over http or ssh)
  * Fixed ``_get_line`` in ``bzrlib.smart.medium``, which was buggy. Also
    fixed ``_get_bytes`` in the same module to use the push back buffer.
    These bugs had no known impact in normal use, but were problematic for
    developers working on the code, and were likely to cause real bugs sooner
    or later
  * Implement handling of basename parameter for DefaultMail
  * Incompatibility with Paramiko versions newer than 1.7.2 was fixed
  * Launchpad locations (lp: URLs) can be pulled
  * Merges that add files to deleted root directories complete. They
    do create conflicts
  * vsftp's return ``550 RNFR command failed.`` supported
  + DOCUMENTATION:
  * Improved documentation on send/merge relationship
  * Minor fixes to the User Guide
  * Reduced the evangelism in the User Guide
  * Added Integrating with Bazaar document for developers
  API BREAKS:
  * Attempting to pull data from a ghost aware repository (e.g. knits) into a
    non-ghost aware repository such as weaves will now fail if there are
    ghosts
  * ``KnitVersionedFile`` no longer accepts an ``access_mode`` parameter, and
    now requires the ``index`` and ``access_method`` parameters to be
    supplied. A compatible shim has been kept in the new function
    ``knit.make_file_knit``
  * Log formatters must now provide log_revision instead of show and
    show_merge_revno methods. The latter had been deprecated since the 0.17
    release
  * ``LoopbackSFTP`` is now called ``SocketAsChannelAdapter``
  * ``osutils.backup_file`` is removed
  * ``Repository.get_revision_graph`` is deprecated, with no replacement
    method. The method was size(history) and not desirable
  * ``revision.revision_graph`` is deprecated, with no replacement function.
    The function was size(history) and not desirable
  * ``Transport.get_shared_medium`` is deprecated. Use
    ``Transport.get_smart_medium`` instead
  * ``VersionedFile`` factories now accept a get_scope parameter rather
    than using a call to ``transaction_finished``, allowing the removal of
    the fixed list of versioned files per repository
  * ``VersionedFile.annotate_iter`` is deprecated. While in principle this
    allowed lower memory use, all users of annotations wanted full file
    annotations, and there is no storage format suitable for incremental
    line-by-line annotation
  * ``VersionedFile.clone_text`` is deprecated. This performance optimisation
    is no longer used - reading the content of a file that is undergoing a
    file level merge to identical state on two branches is rare enough, and
    not expensive enough to special case
  * ``VersionedFile.clear_cache`` and ``enable_cache`` are deprecated.
    These methods added significant complexity to the ``VersionedFile``
    implementation, but were only used for optimising fetches from knits -
    which can be done from outside the knit layer, or via a caching
    decorator. As knits are not the default format, the complexity is no
    longer worth paying
  * ``VersionedFile.create_empty`` is removed. This method presupposed a
    sensible mapping to a transport for individual files, but pack backed
    versioned files have no such mapping
  * ``VersionedFile.get_graph`` is deprecated, with no replacement method.
    The method was size(history) and not desirable
  * ``VersionedFile.get_graph_with_ghosts`` is deprecated, with no
    replacement method. The method was size(history) and not desirable
  * ``VersionedFile.get_parents`` is deprecated, please use
    ``VersionedFile.get_parent_map``
  * ``VersionedFile.get_sha1`` is deprecated, please use
    ``VersionedFile.get_sha1s``
  * ``VersionedFile.has_ghost`` is now deprecated, as it is both expensive
    and unused outside of a single test
  * ``VersionedFile.iter_parents`` is now deprecated in favour of
    ``get_parent_map`` which can be used to instantiate a Graph on a
    VersionedFile
  * ``VersionedFileStore`` no longer uses the transaction parameter given
    to most methods; amongst other things this means that the
    get_weave_or_empty method no longer guarantees errors on a missing weave
    in a readonly transaction, and no longer caches versioned file instances
    which reduces memory pressure (but requires more careful management by
    callers to preserve performance)
  + TESTING:
  * New -Dselftest_debug flag disables clearing of the debug flags during
    tests. This is useful if you want to use e.g. -Dhpss to help debug a
    failing test. Be aware that using this feature is likely to cause
    spurious test failures if used with the full suite
  * selftest --load-list now uses a new more agressive test loader that will
    avoid loading unneeded modules and building their tests. Plugins can use
    this new loader by defining a load_tests function instead of a test_suite
    function. (a forthcoming patch will provide many examples on how to
    implement this)
  * selftest --load-list now does some sanity checks regarding duplicate test
    IDs and tests present in the list but not found in the actual test suite
  * Slightly more concise format for the selftest progress bar, so there's
    more space to show the test name
  * The test suite takes much less memory to run, and is a bit faster. This
    is done by clearing most attributes of TestCases after running them, if
    they succeeded
  + INTERNALS:
  * Added ``_build_client_protocol`` to ``_SmartClient``
  * Added basic infrastructure for automatic plugin suggestion
  * If a ``LockableFiles`` object is not explicitly unlocked (for example
    because of a missing ``try/finally`` block, it will give a warning but
    not automatically unlock itself. (Previously they did.) This
    sometimes caused knock-on errors if for example the network connection
    had already failed, and should not be relied upon by code
  * ``make dist`` target to build a release tarball, and also
    ``check-dist-tarball`` and ``dist-upload-escudero``
  * The ``read_response_tuple`` method of ``SmartClientRequestProtocol*``
    classes will now raise ``UnknownSmartMethod`` when appropriate, so that
    callers don't need to try distinguish unknown request errors from other
    errors
  * ``set_make_working_trees`` is now implemented provided on all repository
    implementations
  * ``VersionedFile`` now has a new method ``get_parent_map`` which, like
    ``Graph.get_parent_map`` returns a dict of key:parents.
* Fri Apr 11 2008 maw@suse.de
- Update to 1.3.1:
  + Fix a bug causing a ValueError crash in
    ``parse_line_delta_iter`` when fetching revisions from a knit
    to pack repository or vice versa using bzr:// (including over
    http or ssh) (Launchpad #208418).
* Wed Apr  9 2008 maw@suse.de
- Make it build on RHEL5, and possibly other related distros.
* Thu Mar 20 2008 maw@suse.de
- Update to 1.3 final:
  + TESTING:
  * Avoid spurious failure of ``TestVersion.test_version``
    matching directory names.
* Tue Mar 18 2008 maw@suse.de
- Build with pyrex.
* Tue Mar 18 2008 maw@suse.de
- Update to 1.3 rc1:
  + CHANGES:
  * A new repository format 'development' has been added. This
    format will represent the latest 'in-progress' format that
    the bzr developers are interested in getting early-adopter
    testing and feedback on;
    ``doc/developers/development-repo.txt`` has detailed
    information
  * BZR_LOG environment variable controls location of .bzr.log
    trace file; user can suppress writing messages to .bzr.log
    by using '/dev/null' filename (on Linux) or 'NUL'
    (on Windows); if BZR_LOG variable is not defined but
    BZR_HOME is defined then default location for .bzr.log
    trace file is ``$BZR_HOME/.bzr.log``
  * ``launchpad`` builtin plugin now shipped as separate part
    in standalone bzr.exe, installed to
    ``C:\Program Files\Bazaar\plugins`` directory, and
    standalone installer allows user to skip installation of
    this plugin
  * Restore auto-detection of plink.exe on Windows
  * Version number is now shown as "1.2" or "1.2pr2", without
    zeroed or missing final fields
  * The backup directory created by ``upgrade`` is now called
    ``backup.bzr``, not ``.bzr.backup``
  + FEATURES:
  * ``branch`` and ``checkout`` can hard-link working tree
    files, which is faster and saves space
  * ``bzr send`` will now also look at the ``child_submit_to``
    setting in the submit branch to determine the email
    address to send to
  + IMPROVEMENTS:
  * BzrBranch._lefthand_history is faster on pack repos
  * Branch6.generate_revision_history is faster
  * Directory services can now be registered, allowing special
    URLs to be dereferenced into real URLs. This is a
    generalization and cleanup of the lp: transport lookup
  * Merge directives that are automatically attached to
    emails have nicer filenames, based on branch-nick + revno
  * ``push`` has a ``--revision`` option, to specify what
    revision to push up to
  * Significantly reducing execution time and network
    traffic for trivial case of running ``bzr missing``
    command for two identical branches
  * Speed up operations that look at the revision graph
    (such as 'bzr log'); ``KnitPackRepositor.get_revision_graph``
    uses ``Graph.iter_ancestry`` to extract the revision
    history; this allows filtering ghosts while stepping
    instead of needing to peek ahead
  * The ``hooks`` command lists installed hooks, to assist
    in debugging
  * Updates to how ``annotate`` work. Should see a measurable
    improvement in performance and memory consumption for
    file with a lot of merges; also, correctly handle when
    a line is introduced by both parents (it should be
    attributed to the first merge which notices this, and not
    too all subsequent merges.)
  + BUGFIXES:
  * Autopacking no longer holds the full set of inventory
    lines in memory while copying; for large repositories,
    this can amount to hundreds of MB of ram consumption
  * Cherrypicking when using ``--format=merge3`` now
    explictly excludes BASE lines
  * Disable plink's interactive prompt for password
  * Encode command line arguments from unicode to
    user_encoding before invoking external mail client in
    `bzr send` command
  * Improved error reporting in the Launchpad plugin
  * Include quick-start-summary.svg file to python-based
    installer(s) for Windows
  * lca merge now respects specified files
  * Make version-info --custom imply --all
  * ``merge --preview`` now works for merges that add
    or modify symlinks
  * Redirecting the output from ``bzr merge`` (when the
    remembered location is used) now works
  * setup.py script explicitly checks for Python version
  * UnknownFormatErrors no longer refer to branches
    regardless of kind of unknown format
  * Upgrade bundled ConfigObj to version 4.5.2, which
    properly quotes #signs, among other small improvements
  * Use correct indices when emitting LCA conflicts; this
    fixes IndexError errors
  + DOCUMENTATION:
  * Explained how to use ``version-info --custom`` in
    the User Guide
  + API BREAKS:
  * Support for loading plugins from zip files and
    ``bzrlib.plugin.load_from_zip()`` function are
    deprecated
  + TESTING:
  * The branch interface tests were invalid for branches
    using rich-root repositories because the empty string
    is not a valid file-id
  + INTERNALS:
  * ``Graph.iter_ancestry`` returns the ancestry of revision
    ids; similar to ``Repository.get_revision_graph()``
    except it includes ghosts and you can stop part-way
    through
  * New module ``tools/package_mf.py`` provide custom module
    finder for python packages (improves standard python
    library's modulefinder.py) used by ``setup.py`` script
    while building standalone bzr.exe
  * New remote method ``RemoteBzrDir.find_repositoryV2``
    adding support for detecting external lookup support
    on remote repositories; this method is now attempted
    first when lookup up repositories, leading to an extra
    round trip on older bzr smart servers
  * Repository formats have a new supported-feature attribute
    ``supports_external_lookups`` used to indicate
    repositories which support falling back to other
    repositories when they have partial data
  * ``Repository.get_revision_graph_with_ghosts`` and
    ``bzrlib.revision.(common_ancestor,MultipleRevisionSources,common_graph)``
    have been deprecated
  * ``Tree.iter_changes`` is now a public API, replacing
    the work-in-progress ``Tree._iter_changes``; the api is
    now considered stable and ready for external users
  * The bzrdir format registry now accepts an ``alias``
    keyword to register_metadir, used to indicate that a
    format name is an alias for some other format and thus
    should not be reported when describing the format.
* Fri Feb 15 2008 maw@suse.de
- Update to 1.2:
  New "merge --preview" shows the diff that would be produced by
  the merge. Operations over bzr+ssh and bzr+http are now faster
  and more robust. Several bugs have been fixed.
  NOTES WHEN UPGRADING:
  * Fetching via the smart protocol may need to reconnect once during a fetch
    if the remote server is running Bazaar 1.1 or earlier, because the client
    attempts to use more efficient requests that confuse older servers. You
    may be required to re-enter a password or passphrase when this happens.
    This won't happen if the server is upgraded to Bazaar 1.2.
    (Andrew Bennetts)
  CHANGES:
  * Fetching via bzr+ssh will no longer fill ghosts by default (this is
    consistent with pack-0.92 fetching over SFTP). (Robert Collins)
  * Formatting of ``bzr plugins`` output is changed to be more human-
    friendly. Full path of plugins locations will be shown only with
    ``--verbose`` command-line option. (Alexander Belchenko)
  * ``merge`` now prefers to use the submit branch, but will fall back to
    parent branch. For many users, this has no effect. But some users who
    pull and merge on the same branch will notice a change. This change
    makes it easier to work on a branch on two different machines, pulling
    between the machines, while merging from the upstream.
    ``merge --remember`` can now be used to set the submit_branch.
    (Aaron Bentley)
  FEATURES:
  * ``merge --preview`` produces a diff of the changes merge would make,
    but does not actually perform the merge. (Aaron Bentley)
  * New smart method ``Repository.get_parent_map`` for getting revision
    parent data. This returns additional parent information topologically
    adjacent to the requested data to reduce round trip latency impacts.
    (Robert Collins)
  * New smart method, ``Repository.stream_revisions_chunked``, for fetching
    revision data that streams revision data via a chunked encoding. This
    avoids buffering large amounts of revision data on the server and on the
    client, and sends less data to the server to request the revisions.
    (Andrew Bennetts, Robert Collins, #178353)
  * The launchpad plugin now handles lp urls of the form
    ``lp://staging/``, ``lp://demo/``, ``lp://dev/`` to use the appropriate
    launchpad instance to do the resolution of the branch identities.
    This is primarily of use to Launchpad developers, but can also
    be used by other users who want to try out Launchpad as
    a branch location without messing up their public Launchpad
    account. Branches that are pushed to the staging environment
    have an expected lifetime of one day. (Tim Penhey)
  IMPROVEMENTS:
  * Creating a new branch no longer tries to read the entire revision-history
    unnecessarily over smart server operations. (Robert Collins)
  * Fetching between different repository formats with compatible models now
    takes advantage of the smart method to stream revisions. (Andrew Bennetts)
  * The ``--coverage`` option is now global, rather specific to ``bzr
    selftest``. (Andrew Bennetts)
  * The ``register-branch`` command will now use the public url of the branch
    containing the current directory, if one has been set and no explicit
    branch is provided. (Robert Collins)
  * Tweak the ``reannotate`` code path to optimize the 2-parent case.
    Speeds up ``bzr annotate`` with a pack repository by approx 3:2.
    (John Arbash Meinel)
  BUGFIXES:
  * Calculate remote path relative to the shared medium in _SmartClient. This
    is related to the problem in bug #124089. (Andrew Bennetts)
  * Cleanly handle connection errors in smart protocol version two, the same
    way as they are handled by version one. (Andrew Bennetts)
  * Clearer error when ``version-info --custom`` is used without
    ``--template`` (Lukáš Lalinský)
  * Don't raise UnavailableFeature during test setup when medusa is not
    available or tearDown is never called leading to nasty side effects.
    (#137823, Vincent Ladeuil)
  * If a plugin's test suite cannot be loaded, for example because of a syntax
    error in the tests, then ``selftest`` fails, rather than just printing
    a warning. (Martin Pool, #189771)
  * List possible values for BZR_SSH environment variable in env-variables
    help topic. (Alexander Belchenko, #181842)
  * New methods ``push_log_file`` and ``pop_log_file`` to intercept messages:
    popping the log redirection now precisely restores the previous state,
    which makes it easier to use bzr log output from other programs.
    TestCaseInTempDir no longer depends on a log redirection being established
    by the test framework, which lets bzr tests cleanly run from a normal
    unittest runner.
    (#124153, #124849, Martin Pool, Jonathan Lange)
  * ``pull --quiet`` is now more quiet, in particular a message is no longer
    printed when the remembered pull location is used. (James Westby,
    [#185907])
  * ``reconfigure`` can safely be interrupted while fetching.
    (Aaron Bentley, #179316)
  * ``reconfigure`` preserves tags when converting to and from lightweight
    checkouts. (Aaron Bentley, #182040)
  * Stop polluting /tmp when running selftest.
    (Vincent Ladeuil, #123623)
  * Switch from NFKC => NFC for normalization checks. NFC allows a few
    more characters which should be considered valid.
    (John Arbash Meinel, #185458)
  * The launchpad plugin now uses the ``edge`` xmlrpc server to avoid
    interacting badly with a bug on the launchpad side. (Robert Collins)
  * Unknown hostnames when connecting to a ``bzr://`` URL no longer cause
    tracebacks. (Andrew Bennetts, #182849)
  API BREAKS:
  * Classes implementing Merge types like Merge3Merger must now accept (and
    honour) a do_merge flag in their constructor. (Aaron Bentley)
  * ``Repository.add_inventory`` and ``add_revision`` now require the caller
    to previously take a write lock (and start a write group.)
    (Martin Pool)
  TESTING:
  * selftest now accepts --load-list <file> to load a test id list. This
    speeds up running the test suite on a limited set of tests.
    (Vincent Ladeuil)
  INTERNALS:
  * Add a new method ``get_result`` to graph search objects. The resulting
    ``SearchResult`` can be used to recreate the search later, which will
    be useful in reducing network traffic. (Robert Collins)
  * Use convenience function to check whether two repository handles
    are referring to the same repository in ``Repository.get_graph``.
    (Jelmer Vernooij, #187162)
  * Fetching now passes the find_ghosts flag through to the
    ``InterRepository.missing_revision_ids`` call consistently for all
    repository types. This will enable faster missing revision discovery with
    bzr+ssh. (Robert Collins)
  * Fix error handling in Repository.insert_data_stream. (Lukas Lalinsky)
  * ``InterRepository.missing_revision_ids`` is now deprecated in favour of
    ``InterRepository.search_missing_revision_ids`` which returns a
    ``bzrlib.graph.SearchResult`` suitable for making requests from the smart
    server. (Robert Collins)
  * New error ``NoPublicBranch`` for commands that need a public branch to
    operate. (Robert Collins)
  * New method ``iter_inventories`` on Repository for access to many
    inventories. This is primarily used by the ``revision_trees`` method, as
    direct access to inventories is discouraged. (Robert Collins)
  * New method ``next_with_ghosts`` on the Graph breadth-first-search objects
    which will split out ghosts and present parents into two separate sets,
    useful for code which needs to be aware of ghosts (e.g. fetching data
    cares about ghosts during revision selection). (Robert Collins)
  * Record a timestamp against each mutter to the trace file, relative to the
    first import of bzrlib. (Andrew Bennetts)
  * ``Repository.get_data_stream`` is now deprecated in favour of
    ``Repository.get_data_stream_for_search`` which allows less network
    traffic when requesting data streams over a smart server. (Robert Collins)
  * ``RemoteBzrDir._get_tree_branch`` no longer triggers ``_ensure_real``,
    removing one round trip on many network operations. (Robert Collins)
  * Repository has a new method ``has_revisions`` which signals the presence
    of many revisions by returning a set of the revisions listed which are
    present. This can be done by index queries without reading data for parent
    revision names etc. (Robert Collins)
  * RemoteTransport's ``recommended_page_size`` method now returns 64k, like
    SFTPTransport and HttpTransportBase. (Andrew Bennetts)
* Tue Jan 15 2008 maw@suse.de
- Update to 1.1:
  + CHANGES:
  * The syntax ``bzr diff branch1 branch2`` is no longer supported.
    Use ``bzr diff branch1 --new branch2`` instead. This change has
    been made to remove the ambiguity where ``branch2`` is in fact a
    s pecific file to diff within ``branch1``.
  + FEATURES:
  * New option to use custom template-based formats in  ``bzr version-info``.
    (Lukáš Lalinský)
  * diff '--using' allows an external diff tool to be used for files.
    (Aaron Bentley)
  * New "lca" merge-type for fast everyday merging that also supports
    criss-cross merges.  (Aaron Bentley)
  + IMPROVEMENTS:
  * ``annotate`` now doesn't require a working tree. (Lukáš Lalinský,
    [#90049])
  * ``branch`` and ``checkout`` can now use files from a working tree to
    to speed up the process.  For checkout, this requires the new
  - -files-from flag.  (Aaron Bentley)
  * ``bzr diff`` now sorts files in alphabetical order.  (Aaron Bentley)
  * ``bzr diff`` now works on branches without working trees. Tree-less
    branches can also be compared to each other and to working trees using
    the new diff options ``--old`` and ``--new``. Diffing between branches,
    with or without trees, now supports specific file filtering as well.
    (Ian Clatworthy, #6700)
  * ``bzr pack`` now orders revision texts in topological order, with newest
    at the start of the file, promoting linear reads for ``bzr log`` and the
    like. This partially fixes #154129. (Robert Collins)
  * Merge directives now fetch prerequisites from the target branch if
    needed.  (Aaron Bentley)
  * pycurl now handles digest authentication.
    (Vincent Ladeuil)
  * ``reconfigure`` can now convert from repositories.  (Aaron Bentley)
  * ``-l`` is now a short form for ``--limit`` in ``log``.  (Matt Nordhoff)
  * ``merge`` now warns when merge directives cause cherrypicks.
    (Aaron Bentley)
  * ``split`` now supported, to enable splitting large trees into smaller
    pieces.  (Aaron Bentley)
  + BUGFIXES:
  * Better handle short reads when processing multiple range requests.
    (Vincent Ladeuil, #179368)
  * build_tree acceleration uses the correct path when a file has been moved.
    (Aaron Bentley)
  * ``commit`` now succeeds when a checkout and its master branch share a
    repository.  (Aaron Bentley, #177592)
  * Fixed error reporting of unsupported timezone format in
    ``log --timezone``. (Lukáš Lalinský, #178722)
  * Fixed Unicode encoding error in ``ignored`` when the output is
    redirected to a pipe. (Lukáš Lalinský)
  * Fix traceback when sending large response bodies over the smart protocol
    on Windows. (Andrew Bennetts, #115781)
  * Fix ``urlutils.relative_url`` for the case of two ``file:///`` URLs
    pointed to different logical drives on Windows.
    (Alexander Belchenko, #90847)
  * HTTP test servers are now compatible with the http protocol version 1.1.
    (Vincent Ladeuil, #175524)
  * _KnitParentsProvider.get_parent_map now handles requests for ghosts
    correctly, instead of erroring or attributing incorrect parents to ghosts.
    (Aaron Bentley)
  * ``merge --weave --uncommitted`` now works.  (Aaron Bentley)
  * pycurl authentication handling was broken and incomplete. Fix handling of
    user:pass embedded in the urls.
    (Vincent Ladeuil, #177643)
  * Files inside non-directories are now handled like other conflict types.
    (Aaron Bentley, #177390)
  * ``reconfigure`` is able to convert trees into lightweight checkouts.
    (Aaron Bentley)
  * Reduce lockdir timeout to 0 when running ``bzr serve``.  (Andrew Bennetts,
    [#148087])
  * Test that the old ``version_info_format`` functions still work, even
    though they are deprecated. (John Arbash Meinel, ShenMaq, #177872)
  * Transform failures no longer cause ImmortalLimbo errors (Aaron Bentley,
    [#137681])
  * ``uncommit`` works even when the commit messages of revisions to be
    removed use characters not supported in the terminal encoding.
    (Aaron Bentley)
  * When dumb http servers return whole files instead of the requested ranges,
    read the remaining bytes by chunks to avoid overflowing network buffers.
    (Vincent Ladeuil, #175886)
  + DOCUMENTATION:
  * Minor tweaks made to the bug tracker integration documentation.
    (Ian Clatworthy)
  * Reference material has now be moved out of the User Guide and added
    to the User Reference. The User Reference has gained 4 sections as
    a result: Authenication Settings, Configuration Settings, Conflicts
    and Hooks. All help topics are now dumped into text format in the
    doc/en/user-reference directory for those who like browsing that
    information in their editor. (Ian Clatworthy)
  * *Using Bazaar with Launchpad* tutorial added. (Ian Clatworthy)
  + INTERNALS:
  * find_* methods available for BzrDirs, Branches and WorkingTrees.
    (Aaron Bentley)
  * Help topics can now be loaded from files.
    (Ian Clatworthy, Alexander Belchenko)
  * get_parent_map now always provides tuples as its output.  (Aaron Bentley)
  * Parent Providers should now implement ``get_parent_map`` returning a
    dictionary instead of ``get_parents`` returning a list.
    ``get_parents`` is now considered deprecated.  (John Arbash Meinel)
  * Patience Diff now supports arbitrary python objects, as long as they
    support ``hash()``. (John Arbash Meinel)
  + TESTING:
  * Modules can now customise their tests by defining a ``load_tests``
    attribute. ``pydoc bzrlib.tests.TestUtil.TestLoader.loadTestsFromModule``
    for the documentation on this attribute. (Robert Collins)
  * New helper function ``bzrlib.tests.condition_id_re`` which helps
    filter tests based on a regular expression search on the tests id.
    (Robert Collins)
  * New helper function ``bzrlib.tests.condition_isinstance`` which helps
    filter tests based on class. (Robert Collins)
  * New helper function ``bzrlib.tests.exclude_suite_by_condition`` which
    generalises the ``exclude_suite_by_re`` function. (Robert Collins)
  * New helper function ``bzrlib.tests.filter_suite_by_condition`` which
    generalises the ``filter_suite_by_re`` function. (Robert Collins)
  * New helper method ``bzrlib.tests.exclude_tests_by_re`` which gives a new
    TestSuite that does not contain tests from the input that matched a
    regular expression. (Robert Collins)
  * New helper method ``bzrlib.tests.randomize_suite`` which returns a
    randomized copy of the input suite. (Robert Collins)
  * New helper method ``bzrlib.tests.split_suite_by_re`` which splits a test
    suite into two according to a regular expression. (Robert Collins)
  * Parametrize all http tests for the transport implementations, the http
    protocol versions (1.0 and 1.1) and the authentication schemes.
    (Vincent Ladeuil)
  * The ``exclude_pattern`` and ``random_order`` parameters to the function
    ``bzrlib.tests.filter_suite_by_re`` have been deprecated. (Robert Collins)
  * The method ``bzrlib.tests.sort_suite_by_re`` has been deprecated. It is
    replaced by the new helper methods added in this release. (Robert Collins)
* Fri Dec 14 2007 maw@suse.de
- Update to 1.0:
  + Documentation updates:
  * User guide improvements
  * Add cherrypicking and rebasing information to the user guide
  * Improve bug tracker integration documentation
  * Minor edits to "Bazaar in five minutes".
* Wed Dec 12 2007 maw@suse.de
- Update to the third release candidate for 1.0:
  + Changes:
  * If a traceback occurs, users are now asked to report the bug
    through Launchpad (https://bugs.launchpad.net/bzr/), rather than
    by mail to the mailing list
  + Bugs fixed:
  * Fix Makefile rules for doc generation
  * Give more feedback during long http downloads by making
    readv deliver data as it arrives for urllib, and issue more
    requests for pycurl. High latency networks are better handled
    by urllib, the pycurl implementation give more feedback but
    also incur more latency
  * Implement _make_parents_provider on RemoteRepository, allowing
    generating bundles against branches on a smart server
  + Documentation:
  * Improved user guide
  * The single-page quick reference guide is now available as a
    PDF
  + Internals:
  * readv urllib http implementation is now a real iterator
    above the underlying socket and deliver data as soon as
    it arrives. 'get' still wraps its output in a StringIO
- Remove bzr-version_info.patch.
* Fri Dec  7 2007 maw@suse.de
- Add bzr-version_info.patch.
* Fri Dec  7 2007 maw@suse.de
- Disable the bzr-zsh package for the time being; it was empty
  anyway
- Fix build.
* Fri Dec  7 2007 maw@suse.de
- Use the bzr.simple bash completion script.
* Fri Dec  7 2007 maw@suse.de
- Update to the second release candidate for 1.0:
  + UI changes:
  * Added a --coverage option to selftest
  * ``bzr commit`` now doesn't print the revision number twice
  * New configuration option ``bugtracker_<tracker_abbrevation>_url`` to
    define locations of bug trackers that are not directly supported by
    bzr or a plugin. The URL will be treated as a template and ``{id}``
    placeholders will be replaced by specific bug IDs.  (Lukáš Lalinský)
  * Support logging single merge revisions with short and line log formatters.
  * User Guide enhanced with suggested readability improvements from
    Matt Revell and corrections from John Arbash Meinel
  * Quick Start Guide renamed to Quick Start Card, moved down in
    the catalog, provided in pdf and png format and updated to refer
    to ``send`` instead of ``bundle``
  * ``switch`` can now be used on heavyweight checkouts as well as
    lightweight ones. After switching a heavyweight checkout, the
    local branch is a mirror/cache of the new bound branch and
    uncommitted changes in the working tree are merged. As a safety
    check, if there are local commits in a checkout which have not
    been committed to the previously bound branch, then ``switch``
    fails unless the ``--force`` option is given. This option is
    now also required if the branch a lightweight checkout is pointing
    to has been moved
  + Internal changes:
  * New -Dhttp debug option reports http connections, requests
    and responses
  * New -Dmerge debug option, which emits merge plans for
    merge-type=weave
  + Bugs fixed (bug numbers here are against launchpad.net):
  * Better error message when running ``bzr cat`` on a non-existant branch.
    (Lukáš Lalinský, #133782)
  * Catch OSError 17 (file exists) in final phase of tree transform and show
    filename to user. (Alexander Belchenko, #111758)
  * Catch ShortReadvErrors while using pycurl. Also make readv more robust by
    allowing multiple GET requests to be issued if too many ranges are
    required (Vincent Ladeuil, #172701)
  * Check for missing basis texts when fetching from packs to packs.
    (John Arbash Meinel, #165290)
  * Fall back to showing e-mail in ``log --short/--line`` if the
    committer/author has only e-mail. (Lukáš Lalinský, #157026)
  + API Breaks:
  * Deprecate not passing a ``location`` argument to commit reporters'
    ``started`` methods. (Matt Nordhoff)
* Tue Dec  4 2007 maw@suse.de
- Use %%{__install} for the emacs and xemacs subpackages
- Create -bash and -zsh (unimplemented) subpackages, providing
  shell completion.
* Tue Dec  4 2007 maw@suse.de
- Create -emacs and -xemacs subpackages which install bzr-mode.el
  for use by those editors.
* Mon Dec  3 2007 maw@suse.de
- Create a debuginfo package.
* Fri Nov 30 2007 maw@suse.de
- Update to the first release candidate for 1.0.
* Fri Nov 30 2007 maw@suse.de
- Create a sftp subpackage that requires paramiko.
* Thu Nov 29 2007 maw@suse.de
- Update to bzr.dev r3048.
* Tue Nov 13 2007 maw@suse.de
- Update to version 0.92.
* Mon Nov  5 2007 maw@suse.de
- Update to revision 2952.
* Mon Oct 29 2007 maw@suse.de
- Update to revision 2948.
* Fri Oct 26 2007 maw@suse.de
- Change version to 0.91.dev.0.r2717 (still rev 2717)
* Fri Oct 26 2007 maw@suse.de
- Change version to 0.92.dev.0 (still rev 2717)
* Fri Oct 26 2007 maw@suse.de
- Update to version 0.92dev0 (rev 2717)
* Thu Sep 27 2007 mrueckert@suse.de
- Update to version 0.91
- python-elementtree is part of the python package since 10.3
  only require it on older distros
* Sat Sep 22 2007 lenz@grimmer.com
- Updated to version 0.90
* Tue Jul 24 2007 lenz@grimmer.com
- Updated to version 0.18
* Mon Apr  2 2007 mrueckert@suse.de
- update to version 0.15:
  This release has much faster working directory options, built-in
  tags on revisions, and many functionality improvements and
  bugfixes.
* Sun Apr  1 2007 mrueckert@suse.de
- update to version 0.14:
  see NEWS file
* Tue Dec  5 2006 mrueckert@suse.de
- update to version 0.13:
  This release fixes a number of bugs. Some highlights include
  the ongoing effort on the smart server, improvements to
  dealing with branches via HTTP (more robust range handling,
  keepalive), and extention of the help system to be able to
  deal with topics that aren't commands.
- changes from version 0.12:
  Lazy imports improve startup time by as much as 50%%. There is
  still room for improvement, but the foundation has been laid.
  Dotted revision numbers: it is now possible to reference
  merged revisions by a short numbered identifier such as "bzr
  diff -r 1.2.1..1.2.3". Support for "bzr+http://", which allows
  communicating with the bzr smart server over an HTTP
  connection.
- removed the mandir patch and replaced it with a setup.py param
* Sun Oct  1 2006 mrueckert@suse.de
- update to version 0.11:
  many small bugfixes and performance improvements
* Thu Sep 28 2006 mrueckert@suse.de
- package more docs
- package tools and contrib
- fix file list for python 2.5
* Mon Sep  4 2006 mrueckert@suse.de
- Updating to version 0.10:
  (quoting from NEWS)
  IMPROVEMENTS:
  * 'merge' now takes --uncommitted, to apply uncommitted changes from a
    tree.  (Aaron Bentley)
  * 'bzr add --file-ids-from' can be used to specify another path to use
    for creating file ids, rather than generating all new ones. Internally,
    the 'action' passed to smart_add_tree() can return file_ids that
    will be used, rather than having bzrlib generate new ones.
    (John Arbash Meinel, #55781)
  * ``bzr selftest --benchmark`` now allows a ``--cache-dir`` parameter.
    This will cache some of the intermediate trees, and decrease the
    setup time for benchmark tests. (John Arbash Meinel)
  * Inverse forms are provided for all boolean options.  For example,
  - -strict has --no-strict, --no-recurse has --recurse (Aaron Bentley)
  * Serialize out Inventories directly, rather than using ElementTree.
    Writing out a kernel sized inventory drops from 2s down to ~350ms.
    (Robert Collins, John Arbash Meinel)
  BUG FIXES:
  * Help diffutils 2.8.4 get along with binary tests (Marien Zwart: #57614)
  * Change LockDir so that if the lock directory doesn't exist when
    lock_write() is called, an attempt will be made to create it.
    (John Arbash Meinel, #56974)
  * ``bzr uncommit`` preserves pending merges. (John Arbash Meinel, #57660)
  * Active FTP transport now works as intended. (ghozzy, #56472)
  * Really fix mutter() so that it won't ever raise a UnicodeError.
    It means it is possible for ~/.bzr.log to contain non UTF-8 characters.
    But it is a debugging log, not a real user file.
    (John Arbash Meinel, #56947, #53880)
  * Change Command handle to allow Unicode command and options.
    At present we cannot register Unicode command names, so we will get
    BzrCommandError('unknown command'), or BzrCommandError('unknown option')
    But that is better than a UnicodeError + a traceback.
    (John Arbash Meinel, #57123)
  * Handle TZ=UTC properly when reading/writing revisions.
    (John Arbash Meinel, #55783, #56290)
  * Use GPG_TTY to allow gpg --cl to work with gpg-agent in a pipeline,
    (passing text to sign in on stdin). (John Arbash Meinel, #54468)
  * External diff does the right thing for binaries even in foreign
    languages. (John Arbash Meinel, #56307)
  * Testament handles more cases when content is unicode. Specific bug was
    in handling of revision properties. (John Arbash Meinel, Holger Krekel,
    [#54723])
  * The bzr selftest was failing on installed versions due to a bug in a new
    test helper. (John Arbash Meinel, Robert Collins, #58057)
* Wed Aug 23 2006 mrueckert@suse.de
- Initial package of version 0.9.0
